##############################################################################
# This code has been written by Adelie Antoine, with the help of Sara Labrousse
# and following P. Goulet's work.
# 
# It is designed to plot the dive profiles, for the 
# whole deployment, and add shading during twilight.
# 
# Last modification : February 2023
##############################################################################

rm(list =ls())


library(oce)

# for sun angle we need :
#     - time as POSIXt (in timezone UTC)
#     - latitude and longitude in degrees north and east


# ============== LOAD DATA FOR ONE INDIVIDUAL ==========================
data_sunangle = read.csv(".../data_for_sunangle_314a.csv")

# ============= ADAPT THE DATAFRAME TO BE PLOTTED IN R =========================
str(data_sunangle)

class(data_sunangle$Var3) = c('POSIXt','POSIXct')

s_angle = sunAngle(data_sunangle$Var3, data_sunangle$Var5, data_sunangle$Var4)
data_sunangle$Var7 = s_angle[["altitude"]]

data_sunangle = subset(data_sunangle, !is.na(Var6))

colnames(data_sunangle) <- c('date1', 'date2', 'date_posix', 'lat', 'lon', 'depth','sunangle')

# select the time arrays for which the period is twilight 
twilight <- data_sunangle %>% 
  filter(sunangle>=-12 & sunangle<=0) %>%
  select(date_posix) %>%
  pull()


# =============== PLOT DIVE DATA AND ADD SHADING ==============================
library(ggplot2)
library(scales)
p1 <- ggplot() + 
  geom_hline(yintercept=0, color = "black", linetype="dashed", linewidth = 0.3)+
  geom_hline(yintercept=-100, color = "black", linetype="dashed", linewidth = 0.3)+
  geom_hline(yintercept=-200, color = "black", linetype="dashed", linewidth = 0.3)+
  geom_hline(yintercept=-300, color = "black", linetype="dashed", linewidth = 0.3)+
  annotate(geom = "rect", 
           xmin = twilight - 0.5, 
           xmax = twilight + 0.5, 
           ymin = -Inf, 
           ymax = Inf, 
           alpha = 0.2, 
           fill = "lightblue") +
geom_line(data=data_sunangle, aes(x = date_posix, y = -depth)) +
  labs(x=" ",y="Depth, m", title = "Individual #1")+
  theme_classic() +
  theme(plot.title = element_text(size=12))

p1
